library qm_tj;

import 'dart:convert';

import 'package:qm_tj/src/utils.dart';

import 'src/db.dart';
import 'package:crypto/crypto.dart' as crypto;
import 'src/tj/app.dart';
import 'src/tj/page.dart';
import 'src/tj/tap.dart';
import 'src/tj/exposure.dart';

class QMTJ {
  static DB _db;
  static App _app;
  static Page _page;
  static Tap _tap;
  static Exposure _exposure;

  static void debug() {
    Utils.debug();
  }

  static init() async {
    _db = DB();
    _app = App(_db);
    _page = Page(_db);
    _tap = Tap(_db);
    _exposure = Exposure(_db);
    _db.init();
    Future.delayed(Duration(seconds: 5)).then((value) {
      _app.upload();
      _page.upload();
      _tap.upload();
      _exposure.upload();
    });
  }

  /// APP 可见
  static void onAppResume({Map<String, dynamic> extras}) async {
    _app.onResume(extras: extras);
  }

  /// APP 不可见
  static void onAppPause() async {
    _app.onPause();
  }

  /// PAGE 可见
  static void onPageResume(
      {String pageId, String lastPageId, Map<String, dynamic> extras}) async {
    _page.onResume(pageId: pageId, lastPageId: lastPageId, extras: extras);
  }

  /// PAGE 不可见
  static void onPagePause(
      {String pageId, String lastPageId, Map<String, dynamic> extras}) async {
    _page.onPause(pageId: pageId, lastPageId: lastPageId, extras: extras);
  }

  /// 点击
  /// [pageId] 页面id
  /// [clickId] 点击id
  /// [extras] 点击参数
  static void tap(
      {String pageId, String clickId, Map<String, dynamic> extras}) async {
    _tap.onTap(pageId: pageId, clickId: clickId, extras: extras);
  }

  /// 曝光
  /// [pageId] 页面id
  /// [exposureId] 曝光id
  /// [extras] 曝光参数
  static void exposure(
      {String pageId, String exposureId, Map<String, dynamic> extras}) async {
    _exposure.onExposure(
        pageId: pageId, exposureId: exposureId, extras: extras);
  }
}
