import 'dart:convert';

import '../../src/db.dart';
import '../../src/utils.dart';

class Page {
  DB _db;

  Page(DB db) {
    _db = db;
  }

  /// 页面回到前台
  void onResume(
      {String pageId, String lastPageId, Map<String, dynamic> extras}) async {
    int disappearTime = 0;
    int appearTime = Utils.getDateNow();
    String extrasStr = json.encode(extras);
    String id = Utils.md5("${pageId}_${lastPageId}_$extrasStr");
    Map<String, dynamic> map = {
      "id": id,
      "page_id": pageId,
      "last_page_id": lastPageId,
      "appear_time": appearTime,
      "disappear_time": disappearTime,
      "extras": json.encode(extras)
    };
    Map<String, dynamic> common = await Utils.getCommonParams();
    map.addAll(common);
    await _db.ready;
    Utils.log("page onResume", map);
    await _db.db.insert("page_tj", map);
  }

  /// 页面进入后台
  void onPause(
      {String pageId, String lastPageId, Map<String, dynamic> extras}) async {
    String extrasStr = json.encode(extras);
    String id = Utils.md5("${pageId}_${lastPageId}_$extrasStr");
    int disappearTime = Utils.getDateNow();
    await _db.ready;
    if (Utils.isDebug) {
      Utils.log("page onPause", {
        "id": id,
        "page_id": pageId,
        "last_page_id": lastPageId,
        "disappear_time": disappearTime,
      });
    }
    await _db.db.update(
        "page_tj",
        {
          "disappear_time": disappearTime,
        },
        where: "id = ?  and disappear_time = 0",
        whereArgs: [id]);
  }

  // 上传数据至接口
  void upload() async {
    await _db.ready;
    List<Map> list = await _db.db.query("page_tj", limit: 100, offset: 0);
    if (list.length == 0) {
      return;
    }
    String deviceId = await Utils.getDeviceId();
    bool result = await Utils.uploadData({
      "device_id": deviceId,
      "projects": [
        {"event_name": "page_scan", "event_data": list}
      ]
    });
    if (result) {
      List<String> ids = List<String>.from(list.map((e) => e['id']).toList());
      await _db.db
          .rawDelete("delete from page_tj where id in('${ids.join("','")}')");
    }
    if (Utils.isDebug) {
      Utils.log("page upload_result", {"ok": result, "length": list.length});
    }
    if (list.length == 100) {
      upload();
    }
  }
}
